==> rustc_1.86.0+dfsg1.orig.tar.xz: rustc-1.86.0-src/src/tools/rustc-perf/collector/compile-benchmarks/stm32f4-0.14.0/src/stm32f405/ethernet_mac/macmiidr.rs <==
#[doc = "Register `MACMIIDR` reader"]
pub struct R(crate::R<MACMIIDR_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<MACMIIDR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<MACMIIDR_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<MACMIIDR_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `MACMIIDR` writer"]
pub struct W(crate::W<MACMIIDR_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<MACMIIDR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<MACMIIDR_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<MACMIIDR_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `TD` reader - TD"]
pub struct TD_R(crate::FieldReader<u16, u16>);
impl TD_R {
    pub(crate) fn new(bits: u16) -> Self {
        TD_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for TD_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `TD` writer - TD"]
pub struct TD_W<'a> {
    w: &'a mut W,
}
impl<'a> TD_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff) | (value as u32 & 0xffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:15 - TD"]
    #[inline(always)]
    pub fn td(&self) -> TD_R {
        TD_R::new((self.bits & 0xffff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:15 - TD"]
    #[inline(always)]
    pub fn td(&mut self) -> TD_W {
        TD_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Ethernet MAC MII data register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [macmiidr](index.html) module"]
pub struct MACMIIDR_SPEC;
impl crate::RegisterSpec for MACMIIDR_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [macmiidr::R](R) reader structure"]
impl crate::Readable for MACMIIDR_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [macmiidr::W](W) writer structure"]
impl crate::Writable for MACMIIDR_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets MACMIIDR to value 0"]
impl crate::Resettable for MACMIIDR_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> rustc_1.92.0+dfsg1.orig.tar.xz: rustc-1.92.0-src/src/tools/rustc-perf/collector/compile-benchmarks/stm32f4-0.15.1/src/stm32f405/ethernet_mac/macmiidr.rs <==
#[doc = "Register `MACMIIDR` reader"]
pub struct R(crate::R<MACMIIDR_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<MACMIIDR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<MACMIIDR_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<MACMIIDR_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `MACMIIDR` writer"]
pub struct W(crate::W<MACMIIDR_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<MACMIIDR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<MACMIIDR_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<MACMIIDR_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `TD` reader - TD"]
pub type TD_R = crate::FieldReader<u16, u16>;
#[doc = "Field `TD` writer - TD"]
pub type TD_W<'a, const O: u8> = crate::FieldWriter<'a, u32, MACMIIDR_SPEC, u16, u16, 16, O>;
impl R {
    #[doc = "Bits 0:15 - TD"]
    #[inline(always)]
    pub fn td(&self) -> TD_R {
        TD_R::new((self.bits & 0xffff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:15 - TD"]
    #[inline(always)]
    pub fn td(&mut self) -> TD_W<0> {
        TD_W::new(self)
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Ethernet MAC MII data register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [macmiidr](index.html) module"]
pub struct MACMIIDR_SPEC;
impl crate::RegisterSpec for MACMIIDR_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [macmiidr::R](R) reader structure"]
impl crate::Readable for MACMIIDR_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [macmiidr::W](W) writer structure"]
impl crate::Writable for MACMIIDR_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets MACMIIDR to value 0"]
impl crate::Resettable for MACMIIDR_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
